pub enum FontWeightStyleValue {
FontWeightAbsolute(FontWeightAbsolute),
Bolder(Ident),
Lighter(Ident),
}Expand description
Represents the style value for font-weight as defined in css-fonts-5.
The font-weight CSS property controls the thickness of a font. It is set explicitly with the keyword bold or a number, or relative to the inherited thickness with the keywords bolder or lighter.
The grammar is defined as:
<font-weight-absolute> | bolder | lighterhttps://drafts.csswg.org/css-fonts-5/#font-weight
Variants