pub struct CommaOrSlash(/* private fields */);Trait Implementations
Sourceimpl Clone for CommaOrSlash
impl Clone for CommaOrSlash
Sourcefn clone(&self) -> CommaOrSlash
fn clone(&self) -> CommaOrSlash
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommaOrSlash
impl Debug for CommaOrSlash
Sourceimpl From<CommaOrSlash> for Cursor
impl From<CommaOrSlash> for Cursor
Sourcefn from(value: CommaOrSlash) -> Cursor
fn from(value: CommaOrSlash) -> Cursor
Converts to this type from the input type.
Sourceimpl From<CommaOrSlash> for Token
impl From<CommaOrSlash> for Token
Sourcefn from(value: CommaOrSlash) -> Token
fn from(value: CommaOrSlash) -> Token
Converts to this type from the input type.
Sourceimpl Hash for CommaOrSlash
impl Hash for CommaOrSlash
Sourceimpl NodeWithMetadata<CssMetadata> for CommaOrSlash
impl NodeWithMetadata<CssMetadata> for CommaOrSlash
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for CommaOrSlash
impl Ord for CommaOrSlash
Sourcefn cmp(&self, other: &CommaOrSlash) -> Ordering
fn cmp(&self, other: &CommaOrSlash) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for CommaOrSlash
impl<'a> Parse<'a> for CommaOrSlash
Sourceimpl PartialEq for CommaOrSlash
impl PartialEq for CommaOrSlash
Sourceimpl PartialOrd for CommaOrSlash
impl PartialOrd for CommaOrSlash
Sourceimpl<'a> Peek<'a> for CommaOrSlash
impl<'a> Peek<'a> for CommaOrSlash
Sourceimpl SemanticEq for CommaOrSlash
impl SemanticEq for CommaOrSlash
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl ToCursors for CommaOrSlash
impl ToCursors for CommaOrSlash
fn to_cursors(&self, s: &mut impl CursorSink)
impl Copy for CommaOrSlash
impl Eq for CommaOrSlash
impl StructuralPartialEq for CommaOrSlash