pub struct CounterName(/* private fields */);Expand description
https://drafts.csswg.org/css-lists-3/#typedef-counter-name
<counter-name> = <custom-ident>Trait Implementations
Sourceimpl Clone for CounterName
impl Clone for CounterName
Sourcefn clone(&self) -> CounterName
fn clone(&self) -> CounterName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CounterName
Sourceimpl Debug for CounterName
impl Debug for CounterName
impl Eq for CounterName
Sourceimpl From<CounterName> for Cursor
impl From<CounterName> for Cursor
Sourcefn from(value: CounterName) -> Cursor
fn from(value: CounterName) -> Cursor
Converts to this type from the input type.
Sourceimpl From<CounterName> for Token
impl From<CounterName> for Token
Sourcefn from(value: CounterName) -> Token
fn from(value: CounterName) -> Token
Converts to this type from the input type.
Sourceimpl Hash for CounterName
impl Hash for CounterName
Sourceimpl NodeWithMetadata<CssMetadata> for CounterName
impl NodeWithMetadata<CssMetadata> for CounterName
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for CounterName
impl Ord for CounterName
Sourcefn cmp(&self, other: &CounterName) -> Ordering
fn cmp(&self, other: &CounterName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for CounterName
impl<'a> Parse<'a> for CounterName
Sourceimpl PartialEq for CounterName
impl PartialEq for CounterName
Sourcefn eq(&self, other: &CounterName) -> bool
fn eq(&self, other: &CounterName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CounterName
impl PartialOrd for CounterName
Sourceimpl<'a> Peek<'a> for CounterName
impl<'a> Peek<'a> for CounterName
Sourceimpl SemanticEq for CounterName
impl SemanticEq for CounterName
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.impl StructuralPartialEq for CounterName
Sourceimpl ToCursors for CounterName
impl ToCursors for CounterName
fn to_cursors(&self, s: &mut impl CursorSink)