pub struct Flex(/* private fields */);Trait Implementations
Sourceimpl NodeWithMetadata<CssMetadata> for Flex
impl NodeWithMetadata<CssMetadata> for Flex
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for Flex
impl Ord for Flex
Sourceimpl PartialOrd for Flex
impl PartialOrd for Flex
Sourceimpl SemanticEq for Flex
impl SemanticEq for Flex
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl ToCursors for Flex
impl ToCursors for Flex
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl ToNumberValue for Flex
impl ToNumberValue for Flex
fn to_number_value(&self) -> Option<f32>
fn to_int_value(&self) -> Option<i32>
impl Copy for Flex
impl Eq for Flex
impl StructuralPartialEq for Flex