pub struct FontSynthesisStyleValue(pub NoneOr<FontSynthesisStyleValueOptions>);Expand description
Represents the style value for font-synthesis as defined in css-fonts-5.
The font-synthesis CSS shorthand property disables all font synthesis except the given kinds. To disable a specific kind of font synthesis, instead use the longhand properties such as font-synthesis-style and font-synthesis-weight.
The grammar is defined as:
none | [ weight || style || small-caps || position]https://drafts.csswg.org/css-fonts-5/#font-synthesis
Tuple Fields
0: NoneOr<FontSynthesisStyleValueOptions>Trait Implementations
Sourceimpl Clone for FontSynthesisStyleValue
impl Clone for FontSynthesisStyleValue
Sourcefn clone(&self) -> FontSynthesisStyleValue
fn clone(&self) -> FontSynthesisStyleValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FontSynthesisStyleValue
impl Debug for FontSynthesisStyleValue
Sourceimpl DeclarationMetadata for FontSynthesisStyleValue
impl DeclarationMetadata for FontSynthesisStyleValue
Sourcefn applies_to() -> AppliesTo
fn applies_to() -> AppliesTo
Determines what types of frames this rule applies to
Sourcefn animation_type() -> AnimationType
fn animation_type() -> AnimationType
Returns how this style value animates
Sourcefn longhands() -> Option<&'static [CssAtomSet]>
fn longhands() -> Option<&'static [CssAtomSet]>
Returns all transitive longhands for a shorthand property.
For nested shorthands (e.g.,
border-width), this recursively expands to include
all nested longhands (e.g., border-top-width, border-left-width, etc.).Sourcefn is_shorthand() -> bool
fn is_shorthand() -> bool
Determines if this style value is a “shorthand” value, meaning it is comprised of other “longhand” style values.
Sourcefn property_group() -> PropertyGroup
fn property_group() -> PropertyGroup
Returns which CSS specification(s) this property belongs to.
This allows tracking which CSS modules are used in a stylesheet.
Sourcefn computed_value_type() -> ComputedValueType
fn computed_value_type() -> ComputedValueType
Returns how the computed value is calculated from the specified value.
Sourcefn canonical_order() -> Option<&'static str>
fn canonical_order() -> Option<&'static str>
Returns the canonical order for serialization (e.g., “per grammar”, “unique”).
Returns None if not specified or not applicable.
Sourcefn percentages() -> Percentages
fn percentages() -> Percentages
Determines how this style value resolves percentages, if they are allowed as values
Sourcefn is_longhand() -> bool
fn is_longhand() -> bool
Determines if this style value is a “longhand” value, meaning a “shorthand” style value exists that could also
express this.
Sourcefn shorthand_group() -> CssAtomSet
fn shorthand_group() -> CssAtomSet
Returns the declaration ID of the shorthand that this property is part of.
If this is not a longhand then it will be
CssAtomSet::_None.Sourcefn logical_property_group() -> Option<CssAtomSet>
fn logical_property_group() -> Option<CssAtomSet>
Returns the logical property group this property belongs to (e.g., “Margin”, “Border”).
This groups related logical/physical properties together.
Returns None if this is not part of a logical property group.
Sourcefn box_side() -> BoxSide
fn box_side() -> BoxSide
Returns which side(s) of the box this property applies to.
For example,
margin-top returns BoxSide::Top, while margin returns all sides.
Returns BoxSide::none() if the property doesn’t apply to a specific side.Sourcefn box_portion() -> BoxPortion
fn box_portion() -> BoxPortion
Returns which portion(s) of the box model this property affects.
For example,
margin-top returns BoxPortion::Margin, border-width returns BoxPortion::Border.
Returns BoxPortion::none() if the property doesn’t affect the box model.Sourcefn unitless_zero_resolves() -> UnitlessZeroResolves
fn unitless_zero_resolves() -> UnitlessZeroResolves
Returns how unitless zero resolves for this property. Read more
impl Eq for FontSynthesisStyleValue
Sourceimpl Hash for FontSynthesisStyleValue
impl Hash for FontSynthesisStyleValue
Sourceimpl NodeWithMetadata<CssMetadata> for FontSynthesisStyleValue
impl NodeWithMetadata<CssMetadata> for FontSynthesisStyleValue
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for FontSynthesisStyleValue
impl Ord for FontSynthesisStyleValue
Sourcefn cmp(&self, other: &FontSynthesisStyleValue) -> Ordering
fn cmp(&self, other: &FontSynthesisStyleValue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for FontSynthesisStyleValue
impl<'a> Parse<'a> for FontSynthesisStyleValue
Sourceimpl PartialEq for FontSynthesisStyleValue
impl PartialEq for FontSynthesisStyleValue
Sourcefn eq(&self, other: &FontSynthesisStyleValue) -> bool
fn eq(&self, other: &FontSynthesisStyleValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FontSynthesisStyleValue
impl PartialOrd for FontSynthesisStyleValue
Sourceimpl<'a> Peek<'a> for FontSynthesisStyleValue
impl<'a> Peek<'a> for FontSynthesisStyleValue
Sourceimpl SemanticEq for FontSynthesisStyleValue
impl SemanticEq for FontSynthesisStyleValue
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.impl StructuralPartialEq for FontSynthesisStyleValue
Sourceimpl ToCursors for FontSynthesisStyleValue
impl ToCursors for FontSynthesisStyleValue
fn to_cursors(&self, s: &mut impl CursorSink)