pub struct LabFunction {
pub name: Function,
pub params: LabFunctionParams,
pub close: RightParen,
}Expand description
https://drafts.csswg.org/css-color/#funcdef-lab
lab() = lab( [<percentage> | <number> | none]
[ <percentage> | <number> | none]
[ <percentage> | <number> | none]
[ / [<alpha-value> | none] ]? )Fields
name: Functionparams: LabFunctionParamsclose: RightParenTrait Implementations
Sourceimpl Clone for LabFunction
impl Clone for LabFunction
Sourcefn clone(&self) -> LabFunction
fn clone(&self) -> LabFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LabFunction
impl Debug for LabFunction
Sourceimpl Hash for LabFunction
impl Hash for LabFunction
Sourceimpl NodeWithMetadata<CssMetadata> for LabFunction
impl NodeWithMetadata<CssMetadata> for LabFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for LabFunction
impl Ord for LabFunction
Sourcefn cmp(&self, other: &LabFunction) -> Ordering
fn cmp(&self, other: &LabFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for LabFunction
impl<'a> Parse<'a> for LabFunction
Sourceimpl PartialEq for LabFunction
impl PartialEq for LabFunction
Sourceimpl PartialOrd for LabFunction
impl PartialOrd for LabFunction
Sourceimpl<'a> Peek<'a> for LabFunction
impl<'a> Peek<'a> for LabFunction
Sourceimpl SemanticEq for LabFunction
impl SemanticEq for LabFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl ToCursors for LabFunction
impl ToCursors for LabFunction
fn to_cursors(&self, s: &mut impl CursorSink)
impl Eq for LabFunction
impl StructuralPartialEq for LabFunction