pub struct Namespace {
pub prefix: Option<NamespacePrefix>,
pub tag: NamespaceTag,
}Expand description
Fields
prefix: Option<NamespacePrefix>tag: NamespaceTagTrait Implementations
impl Copy for Namespace
impl Eq for Namespace
Sourceimpl NodeWithMetadata<CssMetadata> for Namespace
impl NodeWithMetadata<CssMetadata> for Namespace
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for Namespace
impl Ord for Namespace
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Namespace
impl PartialOrd for Namespace
Sourceimpl SemanticEq for Namespace
impl SemanticEq for Namespace
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.impl StructuralPartialEq for Namespace
Sourceimpl ToCursors for Namespace
impl ToCursors for Namespace
fn to_cursors(&self, s: &mut impl CursorSink)