pub struct ShapeFunction<'a> {
pub name: Function,
pub fill_rule: Option<FillRuleStyleValue>,
pub from: Ident,
pub position: Position<'a>,
pub comma: Comma,
pub commands: CommaSeparated<'a, ShapeCommand<'a>>,
pub close: RightParen,
}Expand description
https://drafts.csswg.org/css-shapes/#funcdef-basic-shape-shape
<shape()> = shape(
<'fill-rule'>?
from <position> ,
<shape-command>#
)Fields
name: Functionfill_rule: Option<FillRuleStyleValue>from: Identposition: Position<'a>comma: Commacommands: CommaSeparated<'a, ShapeCommand<'a>>close: RightParenTrait Implementations
Sourceimpl<'a> Clone for ShapeFunction<'a>
impl<'a> Clone for ShapeFunction<'a>
Sourcefn clone(&self) -> ShapeFunction<'a>
fn clone(&self) -> ShapeFunction<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for ShapeFunction<'a>
impl<'a> Debug for ShapeFunction<'a>
impl<'a> Eq for ShapeFunction<'a>
Sourceimpl<'a> Hash for ShapeFunction<'a>
impl<'a> Hash for ShapeFunction<'a>
Sourceimpl<'a> NodeWithMetadata<CssMetadata> for ShapeFunction<'a>
impl<'a> NodeWithMetadata<CssMetadata> for ShapeFunction<'a>
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl<'a> Ord for ShapeFunction<'a>
impl<'a> Ord for ShapeFunction<'a>
Sourcefn cmp(&self, other: &ShapeFunction<'a>) -> Ordering
fn cmp(&self, other: &ShapeFunction<'a>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for ShapeFunction<'a>
impl<'a> Parse<'a> for ShapeFunction<'a>
Sourceimpl<'a> PartialEq for ShapeFunction<'a>
impl<'a> PartialEq for ShapeFunction<'a>
Sourceimpl<'a> PartialOrd for ShapeFunction<'a>
impl<'a> PartialOrd for ShapeFunction<'a>
Sourceimpl<'a> Peek<'a> for ShapeFunction<'a>
impl<'a> Peek<'a> for ShapeFunction<'a>
Sourceimpl<'a> SemanticEq for ShapeFunction<'a>
impl<'a> SemanticEq for ShapeFunction<'a>
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.impl<'a> StructuralPartialEq for ShapeFunction<'a>
Sourceimpl<'a> ToCursors for ShapeFunction<'a>
impl<'a> ToCursors for ShapeFunction<'a>
fn to_cursors(&self, s: &mut impl CursorSink)