pub struct SignFunction<'a, T> {
pub name: Function,
pub params: CalcSum<'a, T>,
pub close: RightParen,
}Expand description
https://drafts.csswg.org/css-values-4/#funcdef-sign
sign( <calc-sum> )Fields
name: Functionparams: CalcSum<'a, T>close: RightParenTrait Implementations
Sourceimpl<'a, T: Clone> Clone for SignFunction<'a, T>
impl<'a, T: Clone> Clone for SignFunction<'a, T>
Sourcefn clone(&self) -> SignFunction<'a, T>
fn clone(&self) -> SignFunction<'a, T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, T: Debug> Debug for SignFunction<'a, T>
impl<'a, T: Debug> Debug for SignFunction<'a, T>
impl<'a, T: Eq> Eq for SignFunction<'a, T>
Sourceimpl<'a, T: Hash> Hash for SignFunction<'a, T>
impl<'a, T: Hash> Hash for SignFunction<'a, T>
Sourceimpl<'a, T> NodeWithMetadata<CssMetadata> for SignFunction<'a, T>
impl<'a, T> NodeWithMetadata<CssMetadata> for SignFunction<'a, T>
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl<'a, T: Ord> Ord for SignFunction<'a, T>
impl<'a, T: Ord> Ord for SignFunction<'a, T>
Sourcefn cmp(&self, other: &SignFunction<'a, T>) -> Ordering
fn cmp(&self, other: &SignFunction<'a, T>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a, T> Parse<'a> for SignFunction<'a, T>
impl<'a, T> Parse<'a> for SignFunction<'a, T>
Sourceimpl<'a, T: PartialEq> PartialEq for SignFunction<'a, T>
impl<'a, T: PartialEq> PartialEq for SignFunction<'a, T>
Sourceimpl<'a, T: PartialOrd> PartialOrd for SignFunction<'a, T>
impl<'a, T: PartialOrd> PartialOrd for SignFunction<'a, T>
Sourceimpl<'a, T> Peek<'a> for SignFunction<'a, T>
impl<'a, T> Peek<'a> for SignFunction<'a, T>
Sourceimpl<'a, T> SemanticEq for SignFunction<'a, T>where
T: SemanticEq,
impl<'a, T> SemanticEq for SignFunction<'a, T>where
T: SemanticEq,
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.impl<'a, T: PartialEq> StructuralPartialEq for SignFunction<'a, T>
Sourceimpl<'a, T> ToCursors for SignFunction<'a, T>where
T: ToCursors,
impl<'a, T> ToCursors for SignFunction<'a, T>where
T: ToCursors,
fn to_cursors(&self, s: &mut impl CursorSink)