pub struct SnapInlineFunction {
pub name: Function,
pub params: SnapInlineFunctionParams,
pub close: RightParen,
}Expand description
https://drafts.csswg.org/css-page-floats-3/#funcdef-float-snap-inline
snap-inline() = snap-inline( <length> , [ left | right | near ]? )Fields
name: Functionparams: SnapInlineFunctionParamsclose: RightParenTrait Implementations
Sourceimpl Clone for SnapInlineFunction
impl Clone for SnapInlineFunction
Sourcefn clone(&self) -> SnapInlineFunction
fn clone(&self) -> SnapInlineFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapInlineFunction
impl Debug for SnapInlineFunction
Sourceimpl Hash for SnapInlineFunction
impl Hash for SnapInlineFunction
Sourceimpl NodeWithMetadata<CssMetadata> for SnapInlineFunction
impl NodeWithMetadata<CssMetadata> for SnapInlineFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for SnapInlineFunction
impl Ord for SnapInlineFunction
Sourcefn cmp(&self, other: &SnapInlineFunction) -> Ordering
fn cmp(&self, other: &SnapInlineFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for SnapInlineFunction
impl<'a> Parse<'a> for SnapInlineFunction
Sourceimpl PartialEq for SnapInlineFunction
impl PartialEq for SnapInlineFunction
Sourceimpl PartialOrd for SnapInlineFunction
impl PartialOrd for SnapInlineFunction
Sourceimpl<'a> Peek<'a> for SnapInlineFunction
impl<'a> Peek<'a> for SnapInlineFunction
Sourceimpl SemanticEq for SnapInlineFunction
impl SemanticEq for SnapInlineFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl ToCursors for SnapInlineFunction
impl ToCursors for SnapInlineFunction
fn to_cursors(&self, s: &mut impl CursorSink)
impl Eq for SnapInlineFunction
impl StructuralPartialEq for SnapInlineFunction